Internal function to calculate the boundary extended time series, to be used within
the TLSW function. Not recommended for general usage.
get.boundary.timeseries(x, type = "TLSW")A vector of 4 times the length of the input vector.
The time series used to calculate the boundary extended version.
The type of boundary handling used. Either "TLSW" (default) for boundary
handling as described in McGonigle, E. T., Killick, R., and Nunes, M. (2022a),
or "LSW.diff" for a periodic version of this, used for the differencing-based functions
as described in McGonigle, E. T., Killick, R., and Nunes, M. (2022b).
McGonigle, E. T., Killick, R., and Nunes, M. (2022a). Trend locally stationary wavelet processes. Journal of Time Series Analysis, 43(6), 895-917.
McGonigle, E. T., Killick, R., and Nunes, M. (2022b). Modelling time-varying first and second-order structure of time series via wavelets and differencing. Electronic Journal of Statistics, 6(2), 4398-4448.
TLSW